@@ -98,7 +98,7 @@
 #'
 #' @references Bartlett JW, Seaman SR, White IR, Carpenter JR. Multiple imputation of covariates
 #' by fully conditional specification: accommodating the substantive model. Statistical Methods
-#' in Medical Research 2015; 24(4): 462-487. \url{http://doi.org/10.1177/0962280214521348}
+#' in Medical Research 2015; 24(4): 462-487. \url{https://doi.org/10.1177/0962280214521348}
 
 #' @import stats
 
@@ -980,8 +980,15 @@ smcfcs.core <- function(originaldata,smtype,smformula,method,predictorMatrix=NUL
     warning(paste("Rejection sampling failed ",rjFailCount," times (across all variables, iterations, and imputations). You may want to increase the rejection sampling limit.",sep=""))
   }
 
-  list(impDatasets=imputations, smCoefIter=smCoefIter)
+  # Added smformula and smtype to metadata, and make "smcfcs class"
+  res <- list(
+    impDatasets = imputations,
+    smCoefIter = smCoefIter,
+    smInfo = list("smtype" = smtype, "smformula" = smformula)
+  )
+  class(res) <- "smcfcs"
 
+  return(res)
 }
 
 updatePassiveVars <- function(data, method, passivecols) {
